Crate strided_view

Crate strided_view 

Device-agnostic strided view types and metadata operations.

This crate is a Rust port of Julia’s StridedViews.jl, providing strided multidimensional array view types with zero-copy metadata transformations.

Core Types

Metadata Transformations

These operate only on dims/strides/offset and never access the underlying data:

  • permute: Reorder dimensions
  • transpose_2d, adjoint_2d: 2D matrix transformations
  • conj: Compose conjugation operation
  • broadcast: Expand size-1 dimensions

Re-exports

pub use view::col_major_strides;
pub use view::row_major_strides;
pub use view::StridedArray;
pub use view::StridedView;
pub use view::StridedViewMut;

Modules

auxiliary
Auxiliary routines ported from StridedViews.jl/src/auxiliary.jl
view
Julia-like dynamic-rank strided view types.

Structs

Adjoint
Adjoint operation: f(x) = adjoint(x) = conj(transpose(x)) For scalar numbers, this is conj.
Conj
Complex conjugate operation: f(x) = conj(x)
ErasedRawStridedMut
Borrowed dtype-erased raw strided output layout.
ErasedRawStridedPtr
Pointer-backed dtype-erased input used by one-shot write entry points.
ErasedRawStridedRef
Borrowed dtype-erased raw strided input layout.
ErasedRawStridedUninitMut
Borrowed dtype-erased raw strided output whose reachable elements may be uninitialized.
Identity
Identity operation: f(x) = x
RawStridedMut
Borrowed raw strided output layout.
RawStridedRef
Borrowed raw strided input layout.
Transpose
Transpose operation: f(x) = transpose(x) For scalar numbers, this is identity. For matrix elements, this would transpose each element.

Enums

KernelDType
Dtypes supported by dtype-erased kernel entry points.
StridedError
Errors that can occur during strided array operations.

Traits

ComposableElementOp
Trait for element operations that support type-level composition.
Compose
Helper trait for composing two ElementOp types.
ElementOp
Trait for element-wise operations applied to strided views.
ElementOpApply
Trait for types that support element operations (conj, transpose, adjoint).
KernelStorageElement
A scalar type that can safely witness storage for an erased kernel view.

Type Aliases

Result
Result type for strided array operations.